@@ -4,12 +4,16 @@ import os
 import sys
 
 import click
-import six
+import sentry_sdk
 from click_aliases import ClickAliasedGroup
+from sentry_sdk.integrations.atexit import AtexitIntegration
+
+import divio_cli
 
 from . import exceptions, localdev, messages, settings
 from .check_system import check_requirements, check_requirements_human
 from .cloud import CloudClient, get_endpoint
+from .excepthook import DivioExcepthookIntegration, divio_shutdown
 from .localdev.utils import allow_remote_id_override
 from .upload.addon import upload_addon
 from .upload.boilerplate import upload_boilerplate
@@ -57,6 +61,12 @@ def cli(ctx, debug, zone, sudo):
     if sudo:
         click.secho("Running as sudo", fg="red")
 
+    ctx.obj = Map()
+    ctx.obj.client = CloudClient(
+        get_endpoint(zone=zone), debug=debug, sudo=sudo
+    )
+    ctx.obj.zone = zone
+
     if debug:
 
         def exception_handler(type, value, traceback):
@@ -72,12 +82,17 @@ def cli(ctx, debug, zone, sudo):
             pdb.post_mortem(traceback)
 
         sys.excepthook = exception_handler
-
-    ctx.obj = Map()
-    ctx.obj.client = CloudClient(
-        get_endpoint(zone=zone), debug=debug, sudo=sudo
-    )
-    ctx.obj.zone = zone
+    else:
+        sentry_sdk.init(
+            ctx.obj.client.config.get_sentry_dsn(),
+            traces_sample_rate=0,
+            release=divio_cli.__version__,
+            server_name="client",
+            integrations=[
+                DivioExcepthookIntegration(),
+                AtexitIntegration(callback=divio_shutdown),
+            ],
+        )
 
     try:
         is_version_command = sys.argv[1] == "version"
@@ -179,7 +194,7 @@ def application_list(obj, grouped, as_json):
         else:
             owner = groups["users"][website["owner_id"]]
         owner["applications"].append(
-            (six.text_type(website["id"]), website["domain"], website["name"])
+            (str(website["id"]), website["domain"], website["name"])
         )
 
     accounts = itertools.chain(
@@ -196,7 +211,7 @@ def application_list(obj, grouped, as_json):
             applications = data["applications"]
             if applications:
                 output_items.append(
-                    u"{title}\n{line}\n\n{table}\n\n".format(
+                    "{title}\n{line}\n\n{table}\n\n".format(
                         title=data["name"],
                         line="=" * len(data["name"]),
                         table=table(
@@ -329,7 +344,7 @@ def application_update(obj, strict):
     "-s",
     "--stage",
     default="test",
-    type=six.text_type,
+    type=str,
     help="Manage the cloud application's environment variables.",
 )
 @click.option(
@@ -343,7 +358,7 @@ def application_update(obj, strict):
     "--get",
     "get_vars",
     default=None,
-    type=six.text_type,
+    type=str,
     multiple=True,
     help="Get a specific environment variable.",
 )
@@ -351,7 +366,7 @@ def application_update(obj, strict):
     "--set",
     "set_vars",
     default=None,
-    type=click.Tuple([six.text_type, six.text_type]),
+    type=click.Tuple([str, str]),
     multiple=True,
     help=(
         "Set a specific custom environment variable\n\n"
@@ -362,7 +377,7 @@ def application_update(obj, strict):
     "--unset",
     "unset_vars",
     default=None,
-    type=six.text_type,
+    type=str,
     multiple=True,
     help="Remove an environment variable.",
 )
@@ -483,13 +498,15 @@ def pull_db(obj, remote_id, stage, prefix, keep_tempfile):
 
     application_home = utils.get_application_home()
     db_type = utils.get_db_type(prefix, path=application_home)
+    dump_path = os.path.join(application_home, settings.DIVIO_DUMP_FOLDER)
+
     localdev.ImportRemoteDatabase(
         client=obj.client,
         stage=stage,
         prefix=prefix,
         remote_id=remote_id,
         db_type=db_type,
-        dump_path=settings.DIVIO_DUMP_FOLDER,
+        dump_path=dump_path,
         keep_tempfile=keep_tempfile,
     )()
 
