@@ -143,19 +143,6 @@ def setup_website_containers(
         return
     docker_compose_config = utils.DockerComposeConfig(docker_compose)
 
-    if docker_compose_config.has_service(
-        "db"
-    ) or docker_compose_config.has_service(
-        "database_{}".format(prefix).lower()
-    ):
-        has_db_service = True
-        existing_db_container_id = utils.get_db_container_id(
-            path=path, raise_on_missing=False
-        )
-    else:
-        has_db_service = False
-        existing_db_container_id = None
-
     # stop all running containers for project
     check_call(docker_compose("stop"))
 
@@ -167,7 +154,11 @@ def setup_website_containers(
     click.secho("building local docker images", fg="green")
     check_call(docker_compose("build"))
 
-    if existing_db_container_id:
+    if docker_compose_config.has_service(
+        "db"
+    ) or docker_compose_config.has_service(
+        "database_{}".format(prefix).lower()
+    ):
         click.secho("removing old database container", fg="green")
         if docker_compose_config.has_service("database_default"):
             check_call(docker_compose("stop", "database_default"), catch=False)
@@ -177,19 +168,20 @@ def setup_website_containers(
         else:
             check_call(docker_compose("stop", "db"))
             check_call(docker_compose("rm", "-f", "db"))
-
-    if has_db_service:
         click.secho("creating new database container", fg="green")
 
         db_type = utils.get_db_type(prefix, path=path)
 
+        application_home = utils.get_application_home(path)
+        dump_path = os.path.join(application_home, settings.DIVIO_DUMP_FOLDER)
+
         ImportRemoteDatabase(
             client=client,
             stage=stage,
             path=path,
             prefix=prefix,
             db_type=db_type,
-            dump_path=settings.DIVIO_DUMP_FOLDER,
+            dump_path=dump_path,
         )()
 
         if needs_legacy_migration():
@@ -691,8 +683,9 @@ class ImportRemoteDatabase(DatabaseImportBase):
             click.secho(" ---> Downloading database", nl=False)
             click.echo(" [{}s]".format(int(time() - start_download)))
             # strip path from dump_path for use in the docker container
-            self.db_dump_path = f"/app/{self.host_db_dump_path}".replace(
-                self.path, ""
+            self.db_dump_path = os.path.join(
+                "/app",
+                self.host_db_dump_path.replace(self.path, "").lstrip("/"),
             )
 
         else:
@@ -787,16 +780,26 @@ def pull_media(client, stage, remote_id=None, path=None):
         # created from within the container will be owned by root. As a
         # workaround, make the folder permissions more permissive, to
         # allow the invoking user to create files inside it.
-        check_call(
-            docker_compose(
-                "run",
-                "--rm",
-                "web",
-                "chown",
-                str(os.getuid()),
-                remote_data_folder,
+        try:
+            check_call(
+                docker_compose(
+                    "run",
+                    "--rm",
+                    "web",
+                    "chown",
+                    str(os.getuid()),
+                    remote_data_folder,
+                ),
+                catch=False,
+            )
+        except subprocess.CalledProcessError as exc:
+            # This can happen due to a race condition in docker compose >= 2
+            click.secho(
+                "Failed to set user ownership of media files.  {}\n".format(
+                    exc
+                ),
+                fg="yellow",
             )
-        )
 
     click.secho(" ---> Extracting files to {}".format(media_path), nl=False)
     start_extract = time()
